c***********************************************************************
c
c       SUBROUTINE BDWT
c
c       ORIGINAL VERSION BY MARK WIEDERSPAN (UTA)
c
c       MODIFIED BY H. VILLINGER DEC 1984
c
c ROUTINE TO CALCULATE THE BULLARD DEPTH WEIGHTINGS. THIS SCHEME WAS
c CONCOCTED BY LISTER TO ACHIEVE THESE ENDS: 1) TO ALLOW THE TWO HALVES
c AROUND AN AVERAGING SENSOR TO BE SEPERATELY CONSIDERED; 2) TO REDUCE
c TO THE SAME WEIGHTING AS THE FULL SPAN WEIGHTING FUNCTION.
c
c IT IS ASSUMED THAT THE PROBE IS OF THE FOLLOWING CONSTRUCTION:
c THERE ARE N (ODD) SENSORS IN A PROBE, N/2+1 POINT SENSORS WHICH
c MEASURE TEMPERATURE IN SOME SMALL REGION, AND N/2 SENSORS WHICH
c AVERAGE TEMPERATURE. THE LATTER ARE COMPRISED OF NINT EQUALLY SPACED
c SENSORS BETWEEN EACH POINT SENSOR. ALL SENSORS ARE IDENTICAL, BUT
c THE AVERAGING 'SENSOR' HAS ELEMENTS CONNECTED IN A SERIES PARALLEL
c COMBINATION TO YIELD THE SAME NOMINAL RESISTANCES AS SINGLE SENSORS.
c
c THIS ROUTINE WILL WEIGHT THE CONTRIBUTIONS OF THE AVERAGING
c SENSORS AND THE POINT SENSORS IN ORDER TO PRODUCE A BULLARD
c DEPTH FOR EACH SENSOR NOMINAL LOCATION. THE FUDGE PARAMETER W IS
c A WAY OF ALTERING THE WEIGHTING FUNCTION. IT WILL BE BETWEEN
c 0 AND 1, THE LATTER APPROPRIATE FOR A MORE SHARPLY CURVING
c CONDUCTIVITY VS. DEPTH RELATION.
c
c TOPHAF AND BOTHAF DO THE WEIGHTING FOR THE TOP AND BOTTOM HALVES
c OF THE AVERAGING SECTION PLUS THE POINT SENSORS AT EACH END
c OF THAT SECTION.
c
c NO ERRORS ARE DERIVED
c
c MAIN MODIFICATION : NO AVERAGING SENSORS INCORPORATED IN THE PROGRAM
c
c***********************************************************************
c
       subroutine bdwt( kmean, n, w, dsensr,
     $              bdepth )
       real kmean(n)
       integer n
       real w
       integer nint
       real dsensr
       real bdepth(n)
c
C THE BOTTOM SENSOR IS 1, THE TOP IS N.
c
       nint = 1
       bdepth(n) = 0.0
c
C BDINC IS THE INCREMENTAL RESISTIVITY ASSOCIATED WITH AN INTERVAL
C THE EVEN ELEMENTS ARE THE AVERAGING SENSORS; ODDS ARE POINT SENSORS
C BDEPTH CONTAINS THE SUM OF THE INCREMENTAL RESISTIVITIES TO A DEPTH
c
       do 100 i = n-1, 1, -1
         if( mod(i,2) .eq. 0 ) then
             bdinc = tophaf( kmean,i,w,nint )
           else
             bdinc = bothaf( kmean,i,w,nint )
         endif
         bdepth(i) = bdepth(i+1) + bdinc
100       continue
c
C COMPUTE BULLARD DEPTH = INTER SENSOR DISTANCE * SUM OF RESISTIVITIES
c
       do 200 i=1,n        
         bdepth(i) = dsensr * bdepth(i)
200       continue
c
       return
       end
c
c
       real function tophaf( kmean, i, w, nint )
       real kmean(1)
       integer i
       real w
       integer nint
c
c
       tophaf = 1.0 / (1.0 + 1.0/nint) *
     $              ( (1.0/nint + w) / kmean(i+1)  +
     $              1.0 / kmean(i)  -
     $              w / kmean(i-1)  )
c
       return
       end
c
c
       real function bothaf( kmean, i, w, nint )
       real kmean(1)
       integer i
       real w
       integer nint
c
c
       bothaf = 1.0 / (1.0 + 1.0/nint) *
     $              ( -w / kmean(i+2)  +
     $              1.0 / kmean(i+1) +
     $              (w + 1.0/nint) / kmean(i)  )
c
       return
       end

