C******************************************************************************
C
C       PROGRAM TO CALCULATE AN F(,) TABLE WITH A  VALUE WHICH
C       HAS TO CHOSEN AT RUN TIME AND WRITES THE TABLE TO A FILE.
C
C       THE FILE NAME WILL BE ASSIGNED AT RUNTIME AND SHOULD BE
C       CHOSEN IN THE FOLLOWING WAY : F<VALUE OF ALPHA>.TAB.
C
C
C       REFERENCE
C       ---------
C       JAEGER, J.C. (1956)
C       CONDUCTION OF HEAT IN AN INFINITE REGION BOUNDED INTERNALLY BY A
C       CIRCULAR CYLINDER OF A PERFECT CONDUCTOR.
C       AUSTRAL.J.PHYSICS,9,167-179.
C
C       VARIABLES
C       --------
C       ALPHA : VALUE OF ALPHA
C       START : START VALUE OF 
C       DTAU : INCREMENT IN 
C
C       THE SUBROUTINES WERE ALL INHERITED FROM LINDA MEINKE, WHO WROTE
C       THEM AT ABOUT 1980 AT THE MIT, BOSTON (MASS.).
C       WE THEREFORE DO NOT COMMENT THEM IN DETAIL BUT DESCRIBE ONLY
C       BRIEFLY WHAT THEY ARE DOING.
C
C       FATEV : SELECTS THE INTEGRATION BOUNDS USED FOR A SPECIFIC
C                VALUE
C       DQG12 : NUMERICAL INTEGRATION 
C       BES : CALCULATION OF BESSEL FUNCTIONS
C       
C******************************************************************************

       program ftable

       implicit double precision (a-h,o-z)
       real ftau(1000),al,dtau,start
       common /one/alpha,a,tau,pi

       write(0,*)'enter alpha, min.tau value and tau-increment'
       read(0,*)al,start,dtau
       a=1.d0

       open(3,file=' ',status='new')

       write(3,*)al,start,dtau

       pi=4.d0*datan(1.d0)
       alpha=dble(al)
       dt=dble(dtau)
       tau=dble(start)-dt
       l=0

       do       100       i=1,1000
       tau=tau+dt
       call fatev(v)
       ftau(i)=sngl(v)
       if(tau.gt.10.d0)   goto 200
       l=l+1
       write(0,*)l,tau,ftau(i)
100       continue

200       write(3,*)(ftau(i),i=1,l)

       stop
       end

