c***********************************************************************
c
c       SUBROUTINE FINRES
c
c       SUBROUTINE PRINTS A TABLE WHICH CONTAINS THE FINAL RESULTS
c       OF THE SEDIMENT TEMPERATURES AND THE THERMAL CONDUCTIVITIES
c       FOR ALL SENSORS.
c       A THERMAL RESISTANCE IS CALCULATED FOR EACH DEPTH WHICH
c       IS USED TO CALCULATE AN INTERVAL HEAT FLOW.
c
c       VARIABLES
c       ---------
c       VARIABLES ARE EXPLAINED ELSEWHERE.
c
c***********************************************************************
c
       subroutine finres(istn,ipen,sedtem,k,pid,weit,npused)
c
       implicit real(k)
       common/sensor/nsensr,tcycle,deltat,a,dsensr,terror,plen,
     $               aa(15),bb(15),cc(15),
     $               ratcl(3),f(5000),alpha,fstart,fincr
       common /out/lundat,lunout,long,lplot
       dimension sedtem(nsensr),k(nsensr),bdepth(20),ipuls(15),
     $           npused(nsensr)
c
c.......
       write(*,*)
       write(*,*)'  ENTER WEIGHTING FACTOR FOR BULLARD-DEPTH'
       write(*,*)'     0. : LINEARLY VARYING CONDUCTIVITY'
       write(*,*)'     1. : SHARP VARIATIONS IN CONDUCTIVITY'
       read(*,*)weit
c
c.......
c
       call bdwt (k,nsensr,weit,dsensr,bdepth)
c
       write(lunout,20)istn,ipen
       write(lunout,30)
       write(lunout,40)
       write(lunout,50)
c
       write(*,20)istn,ipen
       write(*,30)
       write(*,40)
       write(*,50)
c
       l=0
c
       do       100       i=1,nsensr
c
       if(npused(i).eq.0)    then
       l=l+1
       ipuls(l) = i
       endif
c
c.......CALCULATION OF GRADIENT AND INTERVAL HEAT FLOW
c
       depth = (nsensr-i)*dsensr
       if(i.lt.nsensr)     then
       grad = (sedtem(i)-sedtem(i+1))/dsensr
       hf = (sedtem(i)-sedtem(i+1))/(bdepth(i)-bdepth(i+1))
       hf = hf*1000.
       grad = grad*1000.
       endif
c
       write(lunout,60)i,depth,sedtem(i),k(i),bdepth(i)
       write(*,60)i,depth,sedtem(i),k(i),bdepth(i)
       if(i.lt.nsensr)   then
         write(lunout,70) grad,hf
         write(*,70) grad,hf
       endif
c
100       continue
c
c.......
c
       write(lunout,80)weit,pid,(ipuls(j),j=1,l)
       write(*,80)weit,pid,(ipuls(j),j=1,l)
c
c.......
c
20       format(1h1,////,1h ,20x,'HEAT FLOW RESULTS FOR STA ',i2,
     $         ' PEN ',i2)
30       format(1h ,20x,35('='))
40       format(1h ,5x,'sensor',2x,'depth',2x,'sed.temp.',2x,'gradient',
     $         2x,'conductivity',2x,'Bullard-depth',2x,'heat flow')
50       format(1h ,14x,'(m)',5x,'(deg)',4x,'(mdeg/m)',5x,'(W/mk)',
     $         8x,'(m*mK/W)',5x,'(mW/m*m)')
60       format(1h ,5x,i3,6x,f4.2,3x,f6.3,17x,f4.2,11x,f5.3)
70       format(1h ,32x,f6.1,33x,f7.2)
80       format(1h ,/,1h ,5x,'Notes : ',/,
     $        1h ,5x,'(1)  weighting factor for Bullard-depth : ',f4.1
     $        ,/,1h ,5x,'(2) plot id  (0 = no plot) : ',f4.0
     $        ,/,1h ,5x,'(3) assumed conductivities for sensors :',15i3)
c
c.......
c
       return
       end







