c***********************************************************************
c       SUBROUTINE FRIC
c
c       SUBROUTINE TO CALCULATE INFINITE TIME TEMPERATURE FOR SENSOR i
c
c        VARIABLES
c       ---------
c       I : SENSOR NUMBER
c       NUMB : NUMBER OF DATA POINTS AVAILABLE FOR FRICTIONAL DECAY
c       KAPPA : ASSUMED THERMAL CONDUCTIVITY
c       FTAU : F(ALPHA,TAU) VALUES FOR THE DATA POINTS
c       TEM : TEMPERATURE DATA
C       STEM : SEDIMENT TEMPERATURE
c       EST : 95% CONFIDENCE ERROR LIMITS
c       FRMS : RMS ERROR
c       SLOPE : SLOPE OF THE LINEAR REGRESSION OF F(ALPHA,TAU)
c               VS. TEMPERATURE
c       NUSED : NUMBER OF DATA POINTS USED FOR THE CALCULATION OF STEM
c               WITHIN PRESET TAU-WINDOW
c
c
c***********************************************************************
c
       subroutine fric(i,numb,kappa,ftau,tem,
     $                  stem,est,frms,slope,nused)
c
       implicit real (k)
       common/decdat/tfric(75,15),rfric(75,15),
     $                tpuls(75,15),rpuls(75,15)
       common/sensor/nsensr,tcycle,deltat,a,dsensr,terror,plen,
     $                aa(15),bb(15),cc(15),
     $                ratcl(3),f(5000),alpha,fstart,fincr
       common/frico/fdelay(15),dincr,ifmax,tfmin,tfmax
       common/out/lundat,lunout,long,lplot
       dimension tau(75),ftau(75),tem(75),err(75),
     $            ts(50),rms(50)
c
       nused=0
       rms(1) = 0.05
c
c.......SELECTION OF POINTS IN THE PRESET TIME WINDOW
c       NEGATIVE TEMPERATURES ARE EXCLUDED
c
c       THE USER OF THE ALGORITHM SHOULD BE AWARE OF THE FACT
c       THAT IN THE IDEAL CASE WITH PERFECT DATA THE DATA SET 
c       SHOULD BE DECIMATED AT THIS POINT TO EQUALLY SPACED 
c       POINTS IN THE 1/TIME-SPACE. FROM OUR EXPERIENCE WITH 
c       DIFFERENT HEAT FLOW INSTRUMENTS AND THEIR CHARACTERISTIC
c       NOISE PROBLEMS, HOWEVER, INCLUSION OF ADDITIONAL POINTS MAY BE
c       STATISTICALLY WARRENTED.
c
c
       do       100       j=1,numb
       tau(j) = tfric(j,i)
        tau(j) = (kappa * tau(j))/( a*a )
            if(tau(j).ge.tfmin.
     $     and.tau(j).le.tfmax.
     $          and.tau(j).ge.fstart.
     $     and.rfric(j,i).gt.0.0)     then
            nused = nused + 1
            tem(nused) = rfric(j,i)
             tau(nused) = tau(j)
             ftau(nused) = ftable(tau(j))
           err(nused) = terror
       endif
100       continue
c
c.......
c
       if(long.ne.0)   then
         write(lunout,*)'       sensor : ',i
         write(lunout,*)'tau-falphatau-temperature,nfused : ',nused
         do       200       l=1,nused,4
         write(lunout,10)(tau(l+j-1),ftau(l+j-1),tem(l+j-1),j=1,4)
10         format(1h ,4(f5.3,1x,f7.5,1x,f5.3,'*'))
200         continue
         write(lunout,*)'l,ts,inf.time temp,slope,rms'
       endif
c
c.......IF DINCR = 0 THEN NO ITERATION
c
       if(dincr.eq.0.)    then
              call least(tau,tem,err,nused,stem,slope,vara,
     $        varb,covar,cor,frms)
              if(long.ne.0)    then
                     write(lunout,*)'  least squares fit'
                     write(lunout,*)'  sed. temp. : ',stem
                     write(lunout,*)'  slope : ',slope
                     write(lunout,*)'  rms : ',frms
                     write(lunout,*)'  var slope : ',vara
                     write(lunout,*)'  var intercept : ',varb
                     write(lunout,*)'  covar slope-intercept : ',covar
              endif
	      slope = 0.
	      fdelay(i) = 0.
	      est = 2.*frms
	      return
	endif
c
c.......IF NO DATA POINT WITHIN TAU-WINDOW GO TO MAIN PROGRAM
c
       if(nused.eq.0)     return
c
c.......INCREMENTAL INCREASE OF THE DELAY TIME TS
c
       do       400       l=2,ifmax
c
              ts(l) = fdelay(i) + float(l-1)*dincr
c
                     do       500       j=1,nused
                      time = tau(j) + (ts(l)*kappa)/(a*a)
                      ftau(j) = ftable(time)
500                     continue
c
              call least(ftau,tem,err,nused,stem,slope,vara,
     $                   varb,covar,cor,rms(l))
c
               if(long.ne.0)    then
                       write(lunout,*)l,ts(l),stem,slope,rms(l)
              endif
c
              drms = rms(l) - rms(l-1)
c
c.......
c
              if(drms.gt.0.)   then
                      fdelay(i) = ts(l) - dincr/2.
                     goto 1000
              endif
c
400              continue
c
       if(l.gt.ifmax)   fdelay(i)=ts(l-1)
c
c.......FINAL CALCULATION OF THE SEDIMENT TEMPERATURE WITH THE
c       DELAY GIVING THE SMALLEST RMS VALUE
c
1000      do       700       j=1,nused
             time = tau(j) + (fdelay(i)*kappa)/(a*a)
             ftau(j) = ftable(time)
700       continue
c
       call least(ftau,tem,err,nused,stem,slope,vara,
     $             varb,covar,cor,frms)
c
        if(long.ne.0)    then
          write(lunout,*)'  least squares fit'
          write(lunout,*)'  var slope : ',vara
          write(lunout,*)'  var intercept : ',varb
          write(lunout,*)'  covar slope-intercept : ',covar
        endif
c
c.......THE 95% CONFIDENCE ERRORS ARE ASSUMED TO BE TWICE THE
c       STANDART DEVIATION OF THE DATA FIT
c
       est=2.*frms
c
       return
       end


