c***********************************************************************
c
c       SUBROUTINE LEAST
c
c       SUBROUTINE CALCULATES A LINEAR LEAST SQUARE FIT USING THE
c       ASSUMED DATA ERRORS AS WEIGHTS
c
c       VARIABLES
c       ---------
c       X/Y : INPUT DATA
c       ER : ERRORS OF THE Y-VALUES
c       N : NUMBER OF DATA POINTS
c       AXE : INTERCEPT VALUE FOR X=0
c       SLOPE : SLOPE OF THE LINEAR FIT
c       VARA : VARIANCE OF AXE
c       VARB : VARAINCE OF THE SLOPE
c       COVAR : COVARIANCE BETWEEN AXE AND SLOPE
c       COR : CORRELATION  COEFFICIENT
c       RMS : STANDART DEVIATION OF THE FIT
c
c***********************************************************************
c
       subroutine least(x,y,er,n,axe,slope,vara,varb,covar,cor,rms)
c
       double precision a,b,c,d,e,f,det
       dimension x(n),y(n),er(n)
c
       a=0.d0
       b=0.d0
       c=0.d0
       d=0.d0
       e=0.d0
       f=0.d0
c
       do       100       i=1,n
       eror=er(i)**2.d0
       a=a+x(i)/eror
       b=b+1.d0/eror
       c=c+y(i)/eror
       d=d+(x(i)**2.d0)/eror
       e=e+(x(i)*y(i))/eror
       f=f+(y(i)**2.d0)/eror
100       continue
c
       det=b*d-a*a
       slope=sngl((e*b-c*a)/det)
       axe=sngl((d*c-e*a)/det)
       vara=sqrt(sngl(b/det))
       varb=sqrt(sngl(d/det))
       covar=sngl(-a/det)
c
       rms=0.
       do       200       i=1,n
       w=(y(i)-slope*x(i)-axe)**2
       rms=rms+w
200       continue
       rms=sqrt(rms/(n-2))
c
       det=dble(n)*e-a*c
       b=(dble(n)*d-a*a)*(dble(n)*f-c*c)
       b=det/dsqrt(b)
       cor=sngl(b)
c
       return
       end

