c***********************************************************************
c       SUBROUTINE READ
c
c       SUBROUTINE TO READ THE PENETRATION DATA FROM A DATA FILE
c       SPECIFIED IN TITLE
c
c       VARIABLES
c       ---------
c       NFRIC : NUMBER OF DATA POINTS FOR THE FRICTIONAL DECAY
c       NPULS : NUMBER OF DATA POINTS FOR THE HEAT PULSE DECAY
c       RWATER : WATER TEMPERATURES FOR EACH SENSOR
c       FRICON : ORIGIN TIME OF PENETRATION
c       PULSON : ORIGIN TIME OF HEAT PULSE
c
c***********************************************************************
c
       subroutine read( nfric,npuls,rwater,fricon,pulson)
c
       implicit real(k)
       common/decdat/tfric(75,15),rfric(75,15),
     $               tpuls(75,15),rpuls(75,15)
       common/sensor/nsensr,tcycle,deltat,a,dsensr,terror,plen,
     $               aa(15),bb(15),cc(15),
     $               ratcl(3),f(5000),alpha,fstart,fincr
       common/condco/kinit(15),ktoler,tsinit,tsincr,tpmin,tpmax,
     $               ipmax,pdelay(15),power
       common/out/lundat,lunout,long,lplot
       dimension rwater(nsensr),work(16),nfric(nsensr),npuls(nsensr)
c
c.......
c
       do 100 i = 1, nsensr
         nfric(i) = 0
         npuls(i) = 0
100       continue
c
c.......INPUT OF TIMES OF PENETRATION AND HEAT PULSE
c
        read( lundat,*,err=2100,end=2100) fricon
2100        read( lundat,*,err=2200,end=2200 ) pulson
2200       fricon=fricon*tcycle
        pulson=pulson*tcycle
c
       if( long .ne. 0 ) write( lunout,1020 ) fricon,pulson
c
c.......INPUT AND CONVERSION OF WATER TEMPERATURES
c
       read( lundat,* ) (rwater(i),i=1,nsensr)
       do 200 i=1, nsensr
         rwater(i) = temp( rwater(i)/1000., i )
200       continue
c
       if( long .ne. 0 ) write( lunout,2010 ) (rwater(i),i=1,nsensr)
c
c.......READ DATA FROM FILE UNTIL EOF/ERROR/ZEROS
c       THE TIME IS EXPECTED TO BE IN THE FIRST COLUMN
c       DATA WITH A VALUE OF 1023 ARE IGNORED AS THEY INDICATE OVERFLOW
c
300       read( lundat,*,end=500,err=500 ) (work(i),i=1,nsensr+1)
c
       if( work(1) .eq. 0.0 ) goto 500
c
       time=work(1)*tcycle
c
        do 400 i=1,nsensr
         if( work(i+1).eq. 1023 ) then
           goto 400
             else
               if(time.lt.pulson )  then
                    nfric(i)=nfric(i)+1
                    tfric(nfric(i),i)=time-fricon+float(i-1)*deltat
                    rfric(nfric(i),i)=temp(work(i+1)/1000.,i )-rwater(i)
              else
                   npuls(i)=npuls(i)+1
                    tpuls(npuls(i),i)=time-pulson+float(i-1)*deltat
                   rpuls(npuls(i),i)=temp(work(i+1)/1000.,i)-rwater(i)
              endif
             endif
400         continue
c
         goto 300
c
500       continue
c
       close(lundat)
c
c.......
c
       if(long.ne.0)       then
       write(lunout,*)'frictional decay,nfric:',(nfric(i),i=1,nsensr)
       mxfric=nfric(1)
       mxpuls=npuls(1)
       do       600       i=1,nsensr
       if(nfric(i).gt.mxfric)    mxfric=nfric(i)
       if(npuls(i).gt.mxpuls)    mxpuls=npuls(i)
600       continue
       do       700       i=1,mxfric
       write(lunout,3030)i,(tfric(i,l),rfric(i,l),l=1,nsensr)
700       continue
       write(lunout,*)'heat pulse decay,npuls:',(npuls(i),i=1,nsensr)
       do       800       i=1,mxpuls
       write(lunout,3030)i,(tpuls(i,l),rpuls(i,l),l=1,nsensr)
800       continue
       endif
c
c.......
c
1020       format( ' fricon,pulson : ', 2(f6.0,2x))
2010       format( ' water temp = ', 10 (f6.3,1x ))
3030       format(1h ,i2,1x,7(f4.0,1x,f5.3,'|'))
c
       return
       end







